@@ -28,9 +28,12 @@ import botocore.translate
 class TestStubber(unittest.TestCase):
     def setUp(self):
         session = botocore.session.get_session()
-        config = botocore.config.Config(signature_version=botocore.UNSIGNED)
-        self.client = session.create_client('s3', config=config)
-
+        config = botocore.config.Config(
+            signature_version=botocore.UNSIGNED,
+            s3={'addressing_style': 'path'}
+        )
+        self.client = session.create_client(
+            's3', region_name='us-east-1', config=config)
         self.stubber = Stubber(self.client)
 
     def test_stubber_returns_response(self):
@@ -270,3 +273,61 @@ class TestStubber(unittest.TestCase):
         except StubAssertionError:
             self.fail(
                 "Stubber inappropriately raised error for same parameters.")
+
+    def test_no_stub_for_presign_url(self):
+        try:
+            with self.stubber:
+                url = self.client.generate_presigned_url(
+                    ClientMethod='get_object',
+                    Params={
+                        'Bucket': 'mybucket',
+                        'Key': 'mykey'
+                    }
+                )
+                self.assertEqual(
+                    url, 'https://s3.amazonaws.com/mybucket/mykey')
+        except StubResponseError:
+            self.fail(
+                'Stubbed responses should not be required for generating '
+                'presigned requests'
+            )
+
+    def test_can_stub_with_presign_url_mixed_in(self):
+        desired_response = {}
+        expected_params = {
+            'Bucket': 'mybucket',
+            'Prefix': 'myprefix',
+        }
+        self.stubber.add_response(
+            'list_objects', desired_response, expected_params)
+        with self.stubber:
+            url = self.client.generate_presigned_url(
+                ClientMethod='get_object',
+                Params={
+                    'Bucket': 'myotherbucket',
+                    'Key': 'myotherkey'
+                }
+            )
+            self.assertEqual(
+                    url, 'https://s3.amazonaws.com/myotherbucket/myotherkey')
+            actual_response = self.client.list_objects(**expected_params)
+            self.assertEqual(desired_response, actual_response)
+        self.stubber.assert_no_pending_responses()
+
+    def test_parse_get_bucket_location(self):
+        error_code = "NoSuchBucket"
+        error_message = "The specified bucket does not exist"
+        self.stubber.add_client_error(
+            'get_bucket_location', error_code, error_message)
+        self.stubber.activate()
+
+        with self.assertRaises(ClientError):
+            self.client.get_bucket_location(Bucket='foo')
+
+    def test_parse_get_bucket_location_returns_response(self):
+        service_response = {"LocationConstraint": "us-west-2"}
+        self.stubber.add_response('get_bucket_location',service_response)
+        self.stubber.activate()
+        response = self.client.get_bucket_location(Bucket='foo')
+        self.assertEqual(response, service_response)
+
